#include "IMGLoader.h"
//#define FREEIMAGE_LIB // Uncomment for static library - not available for Windows (too large).
#include <FreeImage.h>




bool Image::Load(const char *filename)
{
    if (data != 0)
    {
        delete [] data;
    }

    FreeImage_Initialise();
    FREE_IMAGE_FORMAT fif = FreeImage_GetFileType(filename);
    FIBITMAP *dib = FreeImage_Load(fif, filename);
    FIBITMAP *bmp = dib;
    
    //Convert to OpenGL friendly format - either BGR or BGRA8
    //Allows us to use palettized pictures and transparency
    //without too much worry.
    if (FreeImage_IsTransparent(dib) &&  FreeImage_GetBPP(dib) != 32)
    {
        bmp = FreeImage_ConvertTo32Bits(dib);
    }
    else if (FreeImage_GetBPP(dib) != 24)
    {
        bmp = FreeImage_ConvertTo24Bits(dib);
    }
    
    //store important bits in Image structure in OpenGL friendly format
    sizeX = FreeImage_GetWidth(dib);
    sizeY = FreeImage_GetHeight(dib);
    data = new GLubyte[sizeX*sizeY*3];
    memcpy(data, FreeImage_GetBits(bmp), sizeX*sizeY*3);
    
    //clean up
    if (bmp != dib) FreeImage_Unload(bmp);
    FreeImage_Unload(dib);
    FreeImage_DeInitialise();
    // we're done.
	return true;
}
